]> git.ipfire.org Git - thirdparty/gcc.git/commitdiff
dbxout.c: Follow spelling conventions.
authorKazu Hirata <kazu@cs.umass.edu>
Sun, 22 Sep 2002 14:09:34 +0000 (14:09 +0000)
committerKazu Hirata <kazu@gcc.gnu.org>
Sun, 22 Sep 2002 14:09:34 +0000 (14:09 +0000)
* dbxout.c: Follow spelling conventions.
* defaults.h: Likewise.
* df.c: Likewise.
* diagnostic.h: Likewise.
* doloop.c: Likewise.
* dwarf2out.c: Likewise.
* dwarfout.c: Likewise.
* emit-rtl.c: Likewise.
* except.c: Likewise.
* explow.c: Likewise.
* expmed.c: Likewise.
* expr.c: Likewise.
* expr.h: Likewise.
* flags.h: Likewise.
* flow.c: Likewise.
* fold-const.c: Likewise.
* function.c: Likewise.
* function.h: Likewise.
* gcc.c: Likewise.
* gcov-io.h: Likewise.
* gcov.c: Likewise.
* gcse.c: Likewise.
* genattrtab.c: Likewise.
* genconfig.c: Likewise.
* genrecog.c: Likewise.
* ggc-page.c: Likewise.
* ggc.h: Likewise.
* global.c: Likewise.
* gthr-win32.h: Likewise.
* integrate.c: Likewise.
* jump.c: Likewise.
* langhooks.c: Likewise.
* langhooks.h: Likewise.
* line-map.h: Likewise.
* local-alloc.c: Likewise.
* longlong.h: Likewise.
* loop.c: Likewise.
* loop.h: Likewise.

From-SVN: r57406

39 files changed:
gcc/ChangeLog
gcc/dbxout.c
gcc/defaults.h
gcc/df.c
gcc/diagnostic.h
gcc/doloop.c
gcc/dwarf2out.c
gcc/dwarfout.c
gcc/emit-rtl.c
gcc/except.c
gcc/explow.c
gcc/expmed.c
gcc/expr.c
gcc/expr.h
gcc/flags.h
gcc/flow.c
gcc/fold-const.c
gcc/function.c
gcc/function.h
gcc/gcc.c
gcc/gcov-io.h
gcc/gcov.c
gcc/gcse.c
gcc/genattrtab.c
gcc/genconfig.c
gcc/genrecog.c
gcc/ggc-page.c
gcc/ggc.h
gcc/global.c
gcc/gthr-win32.h
gcc/integrate.c
gcc/jump.c
gcc/langhooks.c
gcc/langhooks.h
gcc/line-map.h
gcc/local-alloc.c
gcc/longlong.h
gcc/loop.c
gcc/loop.h

index 821271cb7c02cbb20ec6ceb60caf773094085658..7c0a807dc13f02bc458ea4da2959f6228ab0fb8b 100644 (file)
@@ -1,3 +1,44 @@
+2002-09-22  Kazu Hirata  <kazu@cs.umass.edu>
+
+       * dbxout.c: Follow spelling conventions.
+       * defaults.h: Likewise.
+       * df.c: Likewise.
+       * diagnostic.h: Likewise.
+       * doloop.c: Likewise.
+       * dwarf2out.c: Likewise.
+       * dwarfout.c: Likewise.
+       * emit-rtl.c: Likewise.
+       * except.c: Likewise.
+       * explow.c: Likewise.
+       * expmed.c: Likewise.
+       * expr.c: Likewise.
+       * expr.h: Likewise.
+       * flags.h: Likewise.
+       * flow.c: Likewise.
+       * fold-const.c: Likewise.
+       * function.c: Likewise.
+       * function.h: Likewise.
+       * gcc.c: Likewise.
+       * gcov-io.h: Likewise.
+       * gcov.c: Likewise.
+       * gcse.c: Likewise.
+       * genattrtab.c: Likewise.
+       * genconfig.c: Likewise.
+       * genrecog.c: Likewise.
+       * ggc-page.c: Likewise.
+       * ggc.h: Likewise.
+       * global.c: Likewise.
+       * gthr-win32.h: Likewise.
+       * integrate.c: Likewise.
+       * jump.c: Likewise.
+       * langhooks.c: Likewise.
+       * langhooks.h: Likewise.
+       * line-map.h: Likewise.
+       * local-alloc.c: Likewise.
+       * longlong.h: Likewise.
+       * loop.c: Likewise.
+       * loop.h: Likewise.
+
 Tue Aug 27 22:26:35 CEST 2002  Jan Hubicka  <jh@suse.cz>
 
        * i386.h (BIGGEST_FIELD_ALIGNMENT): Set proper default for x86_64.
index a570856ad4a62dd8d2dfc319d473244e9f7a6e9e..2ce0fb8ff23de4d03b0722b3163fe6aeea2a884c 100644 (file)
@@ -2460,7 +2460,7 @@ dbxout_finish_symbol (sym)
 #endif
 }
 
-/* Output definitions of all the decls in a chain. Return non-zero if
+/* Output definitions of all the decls in a chain. Return nonzero if
    anything was output */
 
 int
index 700d04e77978c237da4164a69e20f74d3f651696..a3b5f7e8e29595d91e8d3c43b899ca6ec43731d7 100644 (file)
@@ -430,7 +430,7 @@ do { fputs (integer_asm_op (POINTER_SIZE / UNITS_PER_WORD, TRUE), FILE); \
 #endif
 
 /* By default, the C++ compiler will use function addresses in the
-   vtable entries.  Setting this non-zero tells the compiler to use
+   vtable entries.  Setting this nonzero tells the compiler to use
    function descriptors instead.  The value of this macro says how
    many words wide the descriptor is (normally 2).  It is assumed 
    that the address of a function descriptor may be treated as a
index 8918a33c1e04008d5e8d151874136a3a4f887461..6a08e4725db134532ab1e9be660094014cccc55f 100644 (file)
--- a/gcc/df.c
+++ b/gcc/df.c
@@ -2289,7 +2289,7 @@ df_refs_update (df)
 }
 
 
-/* Return non-zero if any of the requested blocks in the bitmap
+/* Return nonzero if any of the requested blocks in the bitmap
    BLOCKS have been modified.  */
 static int
 df_modified_p (df, blocks)
@@ -2951,7 +2951,7 @@ df_insn_dominates_all_uses_p (df, bb, insn)
 }
 
 
-/* Return non-zero if all DF dominates all the uses within the bitmap
+/* Return nonzero if all DF dominates all the uses within the bitmap
    BLOCKS.  */
 static int
 df_def_dominates_uses_p (df, def, blocks)
@@ -2982,7 +2982,7 @@ df_def_dominates_uses_p (df, def, blocks)
 }
 
 
-/* Return non-zero if all the defs of INSN within BB dominates
+/* Return nonzero if all the defs of INSN within BB dominates
    all the corresponding uses.  */
 int
 df_insn_dominates_uses_p (df, bb, insn, blocks)
@@ -3029,7 +3029,7 @@ df_regno_bb (df, regno)
 }
 
 
-/* Return non-zero if REG used in multiple basic blocks.  */
+/* Return nonzero if REG used in multiple basic blocks.  */
 int
 df_reg_global_p (df, reg)
      struct df *df;
@@ -3049,7 +3049,7 @@ df_reg_lifetime (df, reg)
 }
 
 
-/* Return non-zero if REG live at start of BB.  */
+/* Return nonzero if REG live at start of BB.  */
 int
 df_bb_reg_live_start_p (df, bb, reg)
      struct df *df ATTRIBUTE_UNUSED;
@@ -3067,7 +3067,7 @@ df_bb_reg_live_start_p (df, bb, reg)
 }
 
 
-/* Return non-zero if REG live at end of BB.  */
+/* Return nonzero if REG live at end of BB.  */
 int
 df_bb_reg_live_end_p (df, bb, reg)
      struct df *df ATTRIBUTE_UNUSED;
index ff2476815925f744423655092fb1dad279dd70ca..aad9a58cbedff2a11cd852e339a06dfcc609de8d 100644 (file)
@@ -275,7 +275,7 @@ extern diagnostic_context *global_dc;
 /* Similarly, but for sorrys.  */
 #define sorrycount diagnostic_kind_count (global_dc, DK_SORRY)
 
-/* Returns non-zero if warnings should be emitted.  */
+/* Returns nonzero if warnings should be emitted.  */
 #define diagnostic_report_warnings_p()                 \
   (!inhibit_warnings                                   \
    && !(in_system_header && !warn_system_headers))
index f3b302907bc35eb24d18414c55d2ee27489eab53..f79fbad15246ab5d5b67df844c58b72fe642c5ae 100644 (file)
@@ -140,7 +140,7 @@ doloop_condition_get (pattern)
 
 /* Return an estimate of the maximum number of loop iterations for the
    loop specified by LOOP or zero if the loop is not normal.
-   MODE is the mode of the iteration count and NONNEG is non-zero if
+   MODE is the mode of the iteration count and NONNEG is nonzero if
    the iteration count has been proved to be non-negative.  */
 static unsigned HOST_WIDE_INT
 doloop_iterations_max (loop_info, mode, nonneg)
@@ -249,7 +249,7 @@ doloop_iterations_max (loop_info, mode, nonneg)
 }
 
 
-/* Return non-zero if the loop specified by LOOP is suitable for
+/* Return nonzero if the loop specified by LOOP is suitable for
    the use of special low-overhead looping instructions.  */
 static int
 doloop_valid_p (loop, jump_insn)
@@ -399,7 +399,7 @@ doloop_valid_p (loop, jump_insn)
    number of loop iterations, ITERATIONS_MAX is a CONST_INT specifying
    the maximum number of loop iterations, and DOLOOP_INSN is the
    low-overhead looping insn to emit at the end of the loop.  This
-   returns non-zero if it was successful.  */
+   returns nonzero if it was successful.  */
 static int
 doloop_modify (loop, iterations, iterations_max,
               doloop_seq, start_label, condition)
@@ -539,7 +539,7 @@ doloop_modify (loop, iterations, iterations_max,
    not present, we emit one.  The loop to modify is described by LOOP.
    ITERATIONS_MAX is a CONST_INT specifying the estimated maximum
    number of loop iterations.  DOLOOP_INSN is the low-overhead looping
-   insn to insert.  Returns non-zero if loop successfully modified.  */
+   insn to insert.  Returns nonzero if loop successfully modified.  */
 static int
 doloop_modify_runtime (loop, iterations_max,
                       doloop_seq, start_label, mode, condition)
@@ -749,7 +749,7 @@ doloop_modify_runtime (loop, iterations_max,
    suitable.  We distinguish between loops with compile-time bounds
    and those with run-time bounds.  Information from LOOP is used to
    compute the number of iterations and to determine whether the loop
-   is a candidate for this optimization.  Returns non-zero if loop
+   is a candidate for this optimization.  Returns nonzero if loop
    successfully modified.  */
 int
 doloop_optimize (loop)
index f5503d48d653e56d4800aa7b95f33fdbbdecf595..a312332efd5c7f19dc13a6fdcd6266e08a8c64a0 100644 (file)
@@ -1160,7 +1160,7 @@ static dw_cfa_location cfa_temp;
   had better be the one we think we're using for this purpose.
 
   Except: If the register being saved is the CFA register, and the
-  offset is non-zero, we are saving the CFA, so we assume we have to
+  offset is nonzero, we are saving the CFA, so we assume we have to
   use DW_CFA_def_cfa_expression.  If the offset is 0, we assume that
   the intent is to save the value of SP from the previous frame.
 
@@ -3260,7 +3260,7 @@ limbo_die_node;
 #define ASM_COMMENT_START ";#"
 #endif
 
-/* Define a macro which returns non-zero for a TYPE_DECL which was
+/* Define a macro which returns nonzero for a TYPE_DECL which was
    implicitly generated for a tagged type.
 
    Note that unlike the gcc front end (which generates a NULL named
@@ -3846,7 +3846,7 @@ type_main_variant (type)
   return type;
 }
 
-/* Return non-zero if the given type node represents a tagged type.  */
+/* Return nonzero if the given type node represents a tagged type.  */
 
 static inline int
 is_tagged_type (type)
@@ -7439,7 +7439,7 @@ root_type (type)
     }
 }
 
-/* Given a pointer to an arbitrary ..._TYPE tree node, return non-zero if the
+/* Given a pointer to an arbitrary ..._TYPE tree node, return nonzero if the
    given input type is a Dwarf "fundamental" type.  Otherwise return null.  */
 
 static inline int
index ebf5995ca625af979cbc8a791a8ecd7a019c5b3b..9c720dbb85712cb90615b6a54f81fb0517fd512e 100644 (file)
@@ -600,7 +600,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
   fprintf ((FILE), "%s", reg_names[REGNO (RTX)])
 #endif
 
-/* Define a macro which returns non-zero for any tagged type which is
+/* Define a macro which returns nonzero for any tagged type which is
    used (directly or indirectly) in the specification of either some
    function's return type or some formal parameter of some function.
    We use this macro when we are operating in "terse" mode to help us
@@ -612,12 +612,12 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA
    for these nodes.  For now, we have to just fake it.  It it safe for
    us to simply return zero for all complete tagged types (which will
    get forced out anyway if they were used in the specification of some
-   formal or return type) and non-zero for all incomplete tagged types.
+   formal or return type) and nonzero for all incomplete tagged types.
 */
 
 #define TYPE_USED_FOR_FUNCTION(tagged_type) (TYPE_SIZE (tagged_type) == 0)
 
-/* Define a macro which returns non-zero for a TYPE_DECL which was
+/* Define a macro which returns nonzero for a TYPE_DECL which was
    implicitly generated for a tagged type.
 
    Note that unlike the gcc front end (which generates a NULL named
@@ -707,7 +707,7 @@ static unsigned pending_siblings_allocated;
 
 #define PENDING_SIBLINGS_INCREMENT 64
 
-/* Non-zero if we are performing our file-scope finalization pass and if
+/* Nonzero if we are performing our file-scope finalization pass and if
    we should force out Dwarf descriptions of any and all file-scope
    tagged types which are still incomplete types.  */
 
@@ -1325,7 +1325,7 @@ type_main_variant (type)
   return type;
 }
 
-/* Return non-zero if the given type node represents a tagged type.  */
+/* Return nonzero if the given type node represents a tagged type.  */
 
 static inline int
 is_tagged_type (type)
@@ -1950,7 +1950,7 @@ write_modifier_bytes (type, decl_const, decl_volatile)
   write_modifier_bytes_1 (type, decl_const, decl_volatile, 0);
 }
 \f
-/* Given a pointer to an arbitrary ..._TYPE tree node, return non-zero if the
+/* Given a pointer to an arbitrary ..._TYPE tree node, return nonzero if the
    given input type is a Dwarf "fundamental" type.  Otherwise return zero.  */
 
 static inline int
@@ -4533,7 +4533,7 @@ pend_type (type)
   TREE_ASM_WRITTEN (type) = 1;
 }
 
-/* Return non-zero if it is legitimate to output DIEs to represent a
+/* Return nonzero if it is legitimate to output DIEs to represent a
    given type while we are generating the list of child DIEs for some
    DIE (e.g. a function or lexical block DIE) associated with a given scope.
 
index bfcc289cca420c5e53d3f6ee09b8f66bebd0d037..eded8158d53a0e2ddab884a1f04353fcea31a607 100644 (file)
@@ -204,7 +204,7 @@ const_int_htab_hash (x)
   return (hashval_t) INTVAL ((struct rtx_def *) x);
 }
 
-/* Returns non-zero if the value represented by X (which is really a
+/* Returns nonzero if the value represented by X (which is really a
    CONST_INT) is the same as that given by Y (which is really a
    HOST_WIDE_INT *).  */
 
@@ -231,7 +231,7 @@ const_double_htab_hash (x)
   return h;
 }
 
-/* Returns non-zero if the value represented by X (really a ...)
+/* Returns nonzero if the value represented by X (really a ...)
    is the same as that represented by Y (really a ...) */
 static int
 const_double_htab_eq (x, y)
@@ -264,7 +264,7 @@ mem_attrs_htab_hash (x)
          ^ (size_t) p->expr);
 }
 
-/* Returns non-zero if the value represented by X (which is really a
+/* Returns nonzero if the value represented by X (which is really a
    mem_attrs *) is the same as that given by Y (which is also really a
    mem_attrs *).  */
 
@@ -2067,7 +2067,7 @@ adjust_address_1 (memref, mode, offset, validate, adjust)
   unsigned int memalign = MEM_ALIGN (memref);
 
   /* ??? Prefer to create garbage instead of creating shared rtl.
-     This may happen even if offset is non-zero -- consider
+     This may happen even if offset is nonzero -- consider
      (plus (plus reg reg) const_int) -- so do this always.  */
   addr = copy_rtx (addr);
 
@@ -3187,7 +3187,7 @@ mark_label_nuses (x)
 /* Try splitting insns that can be split for better scheduling.
    PAT is the pattern which might split.
    TRIAL is the insn providing PAT.
-   LAST is non-zero if we should return the last insn of the sequence produced.
+   LAST is nonzero if we should return the last insn of the sequence produced.
 
    If this routine succeeds in splitting, it returns the first or last
    replacement insn depending on the value of LAST.  Otherwise, it
index 17eeae1bd8053fe53f8eebd8b092a58da2aeec89..26a231b87dbfd9dd61e62135a45f72547f6d57bb 100644 (file)
@@ -353,7 +353,7 @@ static void sjlj_output_call_site_table             PARAMS ((void));
 
 \f
 /* Routine to see if exception handling is turned on.
-   DO_WARN is non-zero if we want to inform the user that exception
+   DO_WARN is nonzero if we want to inform the user that exception
    handling is turned off.
 
    This is used to ensure that -fexceptions has been specified if the
index 3962a7af0a074b5a22d73bd2cbfb742913ca67a9..8d5114397c979706054bcdcd50e9d067451a1f57 100644 (file)
@@ -823,7 +823,7 @@ copy_to_suggested_reg (x, target, mode)
    PUNSIGNEDP points to the signedness of the type and may be adjusted
    to show what signedness to use on extension operations.
 
-   FOR_CALL is non-zero if this call is promoting args for a call.  */
+   FOR_CALL is nonzero if this call is promoting args for a call.  */
 
 enum machine_mode
 promote_mode (type, mode, punsignedp, for_call)
@@ -1233,7 +1233,7 @@ allocate_dynamic_stack_space (size, target, known_align)
      always know its final value at this point in the compilation (it
      might depend on the size of the outgoing parameter lists, for
      example), so we must align the value to be returned in that case.
-     (Note that STACK_DYNAMIC_OFFSET will have a default non-zero value if
+     (Note that STACK_DYNAMIC_OFFSET will have a default nonzero value if
      STACK_POINTER_OFFSET or ACCUMULATE_OUTGOING_ARGS are defined).
      We must also do an alignment operation on the returned value if
      the stack pointer alignment is less strict that BIGGEST_ALIGNMENT.
index 317dcc4ab540499e8b0f2526377a8b0c5ec1bb61..37622f5ddd07784e77a9b1c3a7584356dd340be6 100644 (file)
@@ -54,7 +54,7 @@ static rtx extract_split_bit_field    PARAMS ((rtx, unsigned HOST_WIDE_INT,
 static void do_cmp_and_jump            PARAMS ((rtx, rtx, enum rtx_code,
                                                 enum machine_mode, rtx));
 
-/* Non-zero means divides or modulus operations are relatively cheap for
+/* Nonzero means divides or modulus operations are relatively cheap for
    powers of two, so don't use branches; emit the operation instead.
    Usually, this will mean that the MD file will emit non-branch
    sequences.  */
@@ -4170,7 +4170,7 @@ make_tree (type, x)
    MODE is the machine mode for the computation.
    X and MULT must have mode MODE.  ADD may have a different mode.
    So can X (defaults to same as MODE).
-   UNSIGNEDP is non-zero to do unsigned multiplication.  */
+   UNSIGNEDP is nonzero to do unsigned multiplication.  */
 
 bool
 const_mult_add_overflow_p (x, mult, add, mode, unsignedp)
@@ -4208,7 +4208,7 @@ const_mult_add_overflow_p (x, mult, add, mode, unsignedp)
    MODE is the machine mode for the computation.
    X and MULT must have mode MODE.  ADD may have a different mode.
    So can X (defaults to same as MODE).
-   UNSIGNEDP is non-zero to do unsigned multiplication.
+   UNSIGNEDP is nonzero to do unsigned multiplication.
    This may emit insns.  */
 
 rtx
@@ -4622,7 +4622,7 @@ emit_store_flag (target, code, op0, op1, mode, unsignedp, normalizep)
   if (code == EQ || code == NE)
     {
       /* For EQ or NE, one way to do the comparison is to apply an operation
-        that converts the operand into a positive number if it is non-zero
+        that converts the operand into a positive number if it is nonzero
         or zero if it was originally zero.  Then, for EQ, we subtract 1 and
         for NE we negate.  This puts the result in the sign bit.  Then we
         normalize with a shift, if needed.
index 4ac7252332f9b376abc60e76e1735cd94689849e..6190866377c9135b5a400704cd667edb7429f629 100644 (file)
@@ -231,7 +231,7 @@ enum insn_code movstr_optab[NUM_MACHINE_MODES];
 /* This array records the insn_code of insns to perform block clears.  */
 enum insn_code clrstr_optab[NUM_MACHINE_MODES];
 
-/* SLOW_UNALIGNED_ACCESS is non-zero if unaligned accesses are very slow.  */
+/* SLOW_UNALIGNED_ACCESS is nonzero if unaligned accesses are very slow.  */
 
 #ifndef SLOW_UNALIGNED_ACCESS
 #define SLOW_UNALIGNED_ACCESS(MODE, ALIGN) STRICT_ALIGNMENT
@@ -4653,7 +4653,7 @@ store_constructor_field (target, bitsize, bitpos, mode, exp, type, cleared,
 {
   if (TREE_CODE (exp) == CONSTRUCTOR
       && bitpos % BITS_PER_UNIT == 0
-      /* If we have a non-zero bitpos for a register target, then we just
+      /* If we have a nonzero bitpos for a register target, then we just
         let store_field do the bitfield handling.  This is unlikely to
         generate unnecessary clear instructions anyways.  */
       && (bitpos == 0 || GET_CODE (target) == MEM))
@@ -9288,7 +9288,7 @@ is_aligning_offset (offset, exp)
 }
 \f
 /* Return the tree node if an ARG corresponds to a string constant or zero
-   if it doesn't.  If we return non-zero, set *PTR_OFFSET to the offset
+   if it doesn't.  If we return nonzero, set *PTR_OFFSET to the offset
    in bytes within the string that ARG is accessing.  The type of the
    offset will be `sizetype'.  */
 
@@ -9674,7 +9674,7 @@ do_jump (exp, if_false_label, if_true_label)
     case NEGATE_EXPR:
     case LROTATE_EXPR:
     case RROTATE_EXPR:
-      /* These cannot change zero->non-zero or vice versa.  */
+      /* These cannot change zero->nonzero or vice versa.  */
       do_jump (TREE_OPERAND (exp, 0), if_false_label, if_true_label);
       break;
 
@@ -9700,7 +9700,7 @@ do_jump (exp, if_false_label, if_true_label)
 #endif
 
     case MINUS_EXPR:
-      /* Non-zero iff operands of minus differ.  */
+      /* Nonzero iff operands of minus differ.  */
       do_compare_and_jump (build (NE_EXPR, TREE_TYPE (exp),
                                  TREE_OPERAND (exp, 0),
                                  TREE_OPERAND (exp, 1)),
@@ -10515,7 +10515,7 @@ do_compare_and_jump (exp, signed_code, unsigned_code, if_false_label,
 
    If TARGET is nonzero, store the result there if convenient.
 
-   If ONLY_CHEAP is non-zero, only do this if it is likely to be very
+   If ONLY_CHEAP is nonzero, only do this if it is likely to be very
    cheap.
 
    Return zero if there is no suitable set-flag instruction
index 470ebd49a17933d77f19002df040826a14c9ecae..e8b2c1760646592c9740dcfa80301690fd55b7f5 100644 (file)
@@ -303,7 +303,7 @@ rtx emit_conditional_move PARAMS ((rtx, enum rtx_code, rtx, rtx,
                                   enum machine_mode, rtx, rtx,
                                   enum machine_mode, int));
 
-/* Return non-zero if the conditional move is supported.  */
+/* Return nonzero if the conditional move is supported.  */
 int can_conditionally_move_p PARAMS ((enum machine_mode mode));
 
 #endif
@@ -439,7 +439,7 @@ extern void use_group_regs PARAMS ((rtx *, rtx));
    If OBJECT has BLKmode, SIZE is its length in bytes.  */
 extern rtx clear_storage PARAMS ((rtx, rtx));
 
-/* Return non-zero if it is desirable to store LEN bytes generated by
+/* Return nonzero if it is desirable to store LEN bytes generated by
    CONSTFUN with several move instructions by store_by_pieces
    function.  CONSTFUNDATA is a pointer which will be passed as argument
    in every CONSTFUN call.
index 4ff7fcf4abf8e314fdfa094642a3fa4f3d09fa7b..f033887e02c1e2852d14e4edf8bfb71f87fa6ff2 100644 (file)
@@ -657,7 +657,7 @@ extern int flag_gcse_sm;
 
 extern int flag_eliminate_dwarf2_dups;
 
-/* Non-zero means to collect statistics which might be expensive
+/* Nonzero means to collect statistics which might be expensive
    and to print them when we are done.  */
 extern int flag_detailed_statistics;
 
index 0c6d614b3b7a8eeb96f1bdd5ba59101550c85896..2905917cbcc7960fbe20d937490b0bb99fed6bc8 100644 (file)
@@ -269,7 +269,7 @@ struct propagate_block_info
   /* The length of mem_set_list.  */
   int mem_set_list_len;
 
-  /* Non-zero if the value of CC0 is live.  */
+  /* Nonzero if the value of CC0 is live.  */
   int cc0_live;
 
   /* Flags controling the set of information propagate_block collects.  */
@@ -797,7 +797,7 @@ update_life_info_in_dirty_blocks (extent, prop_flags)
 
 /* Free the variables allocated by find_basic_blocks.
 
-   KEEP_HEAD_END_P is non-zero if basic_block_info is not to be freed.  */
+   KEEP_HEAD_END_P is nonzero if basic_block_info is not to be freed.  */
 
 void
 free_basic_block_vars (keep_head_end_p)
@@ -2042,7 +2042,7 @@ free_propagate_block_info (pbi)
    case, the resulting set will be equal to the union of the two sets that
    would otherwise be computed.
 
-   Return non-zero if an INSN is deleted (i.e. by dead code removal).  */
+   Return nonzero if an INSN is deleted (i.e. by dead code removal).  */
 
 int
 propagate_block (bb, live, local_set, cond_local_set, flags)
@@ -2096,7 +2096,7 @@ propagate_block (bb, live, local_set, cond_local_set, flags)
    (SET expressions whose destinations are registers dead after the insn).
    NEEDED is the regset that says which regs are alive after the insn.
 
-   Unless CALL_OK is non-zero, an insn is needed if it contains a CALL.
+   Unless CALL_OK is nonzero, an insn is needed if it contains a CALL.
 
    If X is the entire body of an insn, NOTES contains the reg notes
    pertaining to the insn.  */
index c1ea09d7a5a1b4af83208b1144e25fbece7c3e05..2e869017dee72d33d9f0734125f1dbf6f6016255 100644 (file)
@@ -649,7 +649,7 @@ div_and_round_double (code, uns,
       int num_hi_sig, den_hi_sig;
       unsigned HOST_WIDE_INT quo_est, scale;
 
-      /* Find the highest non-zero divisor digit.  */
+      /* Find the highest nonzero divisor digit.  */
       for (i = 4 - 1;; i--)
        if (den[i] != 0)
          {
@@ -1350,7 +1350,7 @@ size_htab_hash (x)
          ^ (TREE_OVERFLOW (t) << 20));
 }
 
-/* Return non-zero if the value represented by *X (an INTEGER_CST tree node)
+/* Return nonzero if the value represented by *X (an INTEGER_CST tree node)
    is the same as that given by *Y, which is the same.  */
 
 static int
@@ -1781,7 +1781,7 @@ truth_value_p (code)
 }
 \f
 /* Return nonzero if two operands are necessarily equal.
-   If ONLY_CONST is non-zero, only return non-zero for constants.
+   If ONLY_CONST is nonzero, only return nonzero for constants.
    This function tests whether the operands are indistinguishable;
    it does not test whether they are equal using C's == operation.
    The distinction is important for IEEE floating point, because
@@ -2015,7 +2015,7 @@ operand_equal_for_comparison_p (arg0, arg1, other)
 /* See if ARG is an expression that is either a comparison or is performing
    arithmetic on comparisons.  The comparisons must only be comparing
    two different values, which will be stored in *CVAL1 and *CVAL2; if
-   they are non-zero it means that some operands have already been found.
+   they are nonzero it means that some operands have already been found.
    No variables may be used anywhere else in the expression except in the
    comparisons.  If SAVE_P is true it means we removed a SAVE_EXPR around
    the expression and save_expr needs to be called with CVAL1 and CVAL2.
@@ -2400,7 +2400,7 @@ distribute_bit_expr (code, type, arg0, arg1)
 }
 \f
 /* Return a BIT_FIELD_REF of type TYPE to refer to BITSIZE bits of INNER
-   starting at BITPOS.  The field is unsigned if UNSIGNEDP is non-zero.  */
+   starting at BITPOS.  The field is unsigned if UNSIGNEDP is nonzero.  */
 
 static tree
 make_bit_field_ref (inner, type, bitsize, bitpos, unsignedp)
@@ -2673,7 +2673,7 @@ decode_field_reference (exp, pbitsize, pbitpos, pmode, punsignedp,
   return inner;
 }
 
-/* Return non-zero if MASK represents a mask of SIZE ones in the low-order
+/* Return nonzero if MASK represents a mask of SIZE ones in the low-order
    bit positions.  */
 
 static int
@@ -4395,7 +4395,7 @@ count_cond (expr, lim)
 /* Transform `a + (b ? x : y)' into `b ? (a + x) : (a + y)'.
    Transform, `a + (x < y)' into `(x < y) ? (a + 1) : (a + 0)'.  Here
    CODE corresponds to the `+', COND to the `(b ? x : y)' or `(x < y)'
-   expression, and ARG to `a'.  If COND_FIRST_P is non-zero, then the
+   expression, and ARG to `a'.  If COND_FIRST_P is nonzero, then the
    COND is the first argument to CODE; otherwise (as in the example
    given here), it is the second argument.  TYPE is the type of the
    original expression.  */
@@ -4527,7 +4527,7 @@ fold_binary_op_with_conditional_arg (code, type, cond, arg, cond_first_p)
    TYPE, X + ADDEND is the same as X.  If NEGATE, return true if X -
    ADDEND is the same as X.
 
-   X + 0 and X - 0 both give X when X is NaN, infinite, or non-zero
+   X + 0 and X - 0 both give X when X is NaN, infinite, or nonzero
    and finite.  The problematic cases are when X is zero, and its mode
    has signed zeros.  In the case of rounding towards -infinity,
    X - 0 is not the same as X because 0 - 0 is -0.  In other rounding
index edc158152d97da9361f1ecac1bc5ba771dc700e3..374ed3c4b89507a9a0396ef2d3caae0877aa4074 100644 (file)
@@ -181,13 +181,13 @@ struct temp_slot GTY(())
   tree type;
   /* The value of `sequence_rtl_expr' when this temporary is allocated.  */
   tree rtl_expr;
-  /* Non-zero if this temporary is currently in use.  */
+  /* Nonzero if this temporary is currently in use.  */
   char in_use;
-  /* Non-zero if this temporary has its address taken.  */
+  /* Nonzero if this temporary has its address taken.  */
   char addr_taken;
   /* Nesting level at which this slot is being used.  */
   int level;
-  /* Non-zero if this should survive a call to free_temp_slots.  */
+  /* Nonzero if this should survive a call to free_temp_slots.  */
   int keep;
   /* The offset of the slot from the frame_pointer, including extra space
      for alignment.  This info is for combine_temp_slots.  */
@@ -3284,7 +3284,7 @@ insns_for_mem_hash (k)
   return (hashval_t) m->key;
 }
 
-/* Return non-zero if K1 and K2 (two REGs) are the same.  */
+/* Return nonzero if K1 and K2 (two REGs) are the same.  */
 
 static int
 insns_for_mem_comp (k1, k2)
@@ -3640,7 +3640,7 @@ instantiate_decls_1 (let, valid_only)
 /* Subroutine of the preceding procedures: Given RTL representing a
    decl and the size of the object, do any instantiation required.
 
-   If VALID_ONLY is non-zero, it means that the RTL should only be
+   If VALID_ONLY is nonzero, it means that the RTL should only be
    changed if the new address is valid.  */
 
 static void
@@ -5204,7 +5204,7 @@ promoted_input_arg (regno, pmode, punsignedp)
    The starting offset and size for this parm are returned in *OFFSET_PTR
    and *ARG_SIZE_PTR, respectively.
 
-   IN_REGS is non-zero if the argument will be passed in registers.  It will
+   IN_REGS is nonzero if the argument will be passed in registers.  It will
    never be set if REG_PARM_STACK_SPACE is not defined.
 
    FNDECL is the function in which the argument was defined.
index dacd63c019e6297779073a4322bf699cc80ba529..c7a5e5e7e3bf6ffc1320fb6c6c2a2737331e8bcb 100644 (file)
@@ -138,7 +138,7 @@ struct expr_status GTY(())
      since code outside the conditional won't know whether or not the
      arguments need to be popped.)
 
-     When INHIBIT_DEFER_POP is non-zero, however, the compiler does not
+     When INHIBIT_DEFER_POP is nonzero, however, the compiler does not
      attempt to defer pops.  Instead, the stack is popped immediately
      after each call.  Rather then setting this variable directly, use
      NO_DEFER_POP and OK_DEFER_POP.  */
@@ -222,7 +222,7 @@ struct function GTY(())
      used for the current function's args.  */
   CUMULATIVE_ARGS args_info;
 
-  /* If non-zero, an RTL expression for the location at which the current 
+  /* If nonzero, an RTL expression for the location at which the current
      function returns its result.  If the current function returns its
      result in a register, current_function_return_rtx will always be
      the hard register containing the result.  */
index 3bff09a5bf636b2a72a875ba7988dece32cc6464..2210e2d2ea68a4936abb16d11f3d8bd70cd43bf9 100644 (file)
--- a/gcc/gcc.c
+++ b/gcc/gcc.c
@@ -234,7 +234,7 @@ modify_target[] = MODIFY_TARGET_NAME;
 #endif
 
 /* The number of errors that have occurred; the link phase will not be
-   run if this is non-zero.  */
+   run if this is nonzero.  */
 static int error_count = 0;
 
 /* Greatest exit code of sub-processes that has been encountered up to
@@ -2151,7 +2151,7 @@ clear_failure_queue ()
 \f
 /* Build a list of search directories from PATHS.
    PREFIX is a string to prepend to the list.
-   If CHECK_DIR_P is non-zero we ensure the directory exists.
+   If CHECK_DIR_P is nonzero we ensure the directory exists.
    This is used mostly by putenv_from_prefixes so we use `collect_obstack'.
    It is also used by the --print-search-dirs flag.  */
 
index 4c547b5969db3508dbf9324ac17c8cb1dcc80c9f..29a44017fde87ece5604b3943ead785dcd5eb8c6 100644 (file)
@@ -46,7 +46,7 @@ static int __read_gcov_string PARAMS ((char *, size_t, FILE*, long))
 /* These routines only work for signed values.  */
 
 /* Store a portable representation of VALUE in DEST using BYTES*8-1 bits.
-   Return a non-zero value if VALUE requires more than BYTES*8-1 bits
+   Return a nonzero value if VALUE requires more than BYTES*8-1 bits
    to store.  */
 
 static int
@@ -81,7 +81,7 @@ __store_gcov_type (value, dest, bytes)
 }
 
 /* Retrieve a quantity containing BYTES*8-1 bits from SOURCE and store
-   the result in DEST. Returns a non-zero value if the value in SOURCE
+   the result in DEST. Returns a nonzero value if the value in SOURCE
    will not fit in DEST.  */
 
 static int
@@ -130,7 +130,7 @@ __fetch_long (dest, source, bytes)
   return 0;
 }
 
/* Write a BYTES*8-bit quantity to FILE, portably. Returns a non-zero
    value if the write fails, or if VALUE can't be stored in BYTES*8
    bits.
 
@@ -168,7 +168,7 @@ __write_long (value, file, bytes)
 }
 
 /* Read a quantity containing BYTES bytes from FILE, portably. Return
-   a non-zero value if the read fails or if the value will not fit
+   a nonzero value if the read fails or if the value will not fit
    in DEST.
 
    Note that DEST may not be large enough to hold all of the requested
index 38a8293327e244c8f6303867e09c9211af5eb6e8..2360b0a25d41c74212c5e60817212384ee1f4f7b 100644 (file)
@@ -238,7 +238,7 @@ static int output_long_names = 0;
 static int output_function_summary = 0;
 
 /* Object directory file prefix.  This is the directory/file
-   where .bb and .bbg files are looked for, if non-zero.  */
+   where .bb and .bbg files are looked for, if nonzero.  */
 
 static char *object_directory = 0;
 
@@ -1055,7 +1055,7 @@ scan_for_source_files ()
        }
       /* There will be a zero before the first file name, in which case s_ptr
         will still be uninitialized.  So, only try to set the maxlineno
-        field if line_num is non-zero.  */
+        field if line_num is nonzero.  */
       else if (line_num > 0)
        {
          if (s_ptr->maxlineno <= line_num)
index 2af1122282abb3a29d8414e8ab1252257e0dfbec..fbe3fcb1200782106c2f5d31ef0a3eac9be84f2e 100644 (file)
@@ -297,12 +297,12 @@ static FILE *debug_stderr;
 /* An obstack for our working variables.  */
 static struct obstack gcse_obstack;
 
/* Non-zero for each mode that supports (set (reg) (reg)).
    This is trivially true for integer and floating point values.
    It may or may not be true for condition codes.  */
 static char can_copy_p[(int) NUM_MACHINE_MODES];
 
/* Non-zero if can_copy_p has been initialized.  */
 static int can_copy_init_p;
 
 struct reg_use {rtx reg_rtx; };
@@ -344,9 +344,9 @@ struct occr
   struct occr *next;
   /* The insn that computes the expression.  */
   rtx insn;
/* Non-zero if this [anticipatable] occurrence has been deleted.  */
   char deleted_p;
/* Non-zero if this [available] occurrence has been copied to
      reaching_reg.  */
   /* ??? This is mutually exclusive with deleted_p, so they could share
      the same byte.  */
@@ -1157,7 +1157,7 @@ compute_local_properties (transp, comp, antloc, table)
            compute_transp (expr->expr, indx, transp, table->set_p);
 
          /* The occurrences recorded in antic_occr are exactly those that
-            we want to set to non-zero in ANTLOC.  */
+            we want to set to nonzero in ANTLOC.  */
          if (antloc)
            for (occr = expr->antic_occr; occr != NULL; occr = occr->next)
              {
@@ -1169,7 +1169,7 @@ compute_local_properties (transp, comp, antloc, table)
              }
 
          /* The occurrences recorded in avail_occr are exactly those that
-            we want to set to non-zero in COMP.  */
+            we want to set to nonzero in COMP.  */
          if (comp)
            for (occr = expr->avail_occr; occr != NULL; occr = occr->next)
              {
@@ -1341,7 +1341,7 @@ want_to_gcse_p (x)
          && (num_clobbers == 0 || ! added_clobbers_hard_reg_p (icode)));
 }
 
/* Return non-zero if the operands of expression X are unchanged from the
    start of INSN's basic block up to but not including INSN (if AVAIL_P == 0),
    or from INSN to the end of INSN's basic block (if AVAIL_P != 0).  */
 
@@ -1524,7 +1524,7 @@ load_killed_in_block_p (bb, uid_limit, x, avail_p)
   return 0;
 }
 
/* Return non-zero if the operands of expression X are unchanged from
    the start of INSN's basic block up to but not including INSN.  */
 
 static int
@@ -1534,7 +1534,7 @@ oprs_anticipatable_p (x, insn)
   return oprs_unchanged_p (x, insn, 0);
 }
 
/* Return non-zero if the operands of expression X are unchanged from
    INSN to the end of INSN's basic block.  */
 
 static int
@@ -1787,7 +1787,7 @@ hash_set (regno, hash_table_size)
   return hash % hash_table_size;
 }
 
/* Return non-zero if exp1 is equivalent to exp2.
    ??? Borrowed from cse.c.  Might want to remerge with cse.c.  Later.  */
 
 static int
@@ -1937,8 +1937,8 @@ expr_equiv_p (x, y)
    MODE is the mode of the value X is being stored into.
    It is only used if X is a CONST_INT.
 
-   ANTIC_P is non-zero if X is an anticipatable expression.
-   AVAIL_P is non-zero if X is an available expression.  */
+   ANTIC_P is nonzero if X is an anticipatable expression.
+   AVAIL_P is nonzero if X is an available expression.  */
 
 static void
 insert_expr_in_table (x, mode, insn, antic_p, avail_p, table)
@@ -2255,7 +2255,7 @@ hash_scan_call (x, insn, table)
    that isn't dealt with right now.  The trick is handling the CLOBBERs that
    are also in the PARALLEL.  Later.
 
-   If SET_P is non-zero, this is for the assignment hash table,
+   If SET_P is nonzero, this is for the assignment hash table,
    otherwise it is for the expression hash table.
    If IN_LIBCALL_BLOCK nonzero, we are in a libcall block, and should
    not record any expressions.  */
@@ -2740,7 +2740,7 @@ reset_opr_set_tables ()
   clear_modify_mem_tables ();
 }
 
/* Return non-zero if the operands of X are not set before INSN in
    INSN's basic block.  */
 
 static int
@@ -3068,7 +3068,7 @@ compute_ae_gen (expr_hash_table)
        SET_BIT (ae_gen[BLOCK_NUM (occr->insn)], expr->bitmap_index);
 }
 
/* Return non-zero if expression X is killed in BB.  */
 
 static int
 expr_killed_p (x, bb)
@@ -3157,9 +3157,9 @@ compute_ae_kill (ae_gen, ae_kill, expr_hash_table)
 \f
 /* Actually perform the Classic GCSE optimizations.  */
 
/* Return non-zero if occurrence OCCR of expression EXPR reaches block BB.
 
-   CHECK_SELF_LOOP is non-zero if we should consider a block reaching itself
+   CHECK_SELF_LOOP is nonzero if we should consider a block reaching itself
    as a positive reach.  We want to do this when there are two computations
    of the expression in the block.
 
@@ -3318,7 +3318,7 @@ computing_insn (expr, insn)
     }
 }
 
/* Return non-zero if the definition in DEF_INSN can reach INSN.
    Only called by can_disregard_other_sets.  */
 
 static int
@@ -3352,7 +3352,7 @@ def_reaches_here_p (insn, def_insn)
   return 0;
 }
 
/* Return non-zero if *ADDR_THIS_REG can only have one value at INSN.  The
    value returned is the number of definitions that reach INSN.  Returning a
    value of zero means that [maybe] more than one definition reaches INSN and
    the caller can't perform whatever optimization it is trying.  i.e. it is
@@ -3404,7 +3404,7 @@ can_disregard_other_sets (addr_this_reg, insn, for_combine)
 /* Expression computed by insn is available and the substitution is legal,
    so try to perform the substitution.
 
-   The result is non-zero if any changes were made.  */
+   The result is nonzero if any changes were made.  */
 
 static int
 handle_avail_expr (insn, expr)
@@ -3562,7 +3562,7 @@ handle_avail_expr (insn, expr)
 /* Perform classic GCSE.  This is called by one_classic_gcse_pass after all
    the dataflow analysis has been done.
 
-   The result is non-zero if a change was made.  */
+   The result is nonzero if a change was made.  */
 
 static int
 classic_gcse ()
@@ -3621,7 +3621,7 @@ classic_gcse ()
 
 /* Top level routine to perform one classic GCSE pass.
 
-   Return non-zero if a change was made.  */
+   Return nonzero if a change was made.  */
 
 static int
 one_classic_gcse_pass (pass)
@@ -3917,7 +3917,7 @@ find_used_regs (xptr, data)
 }
 
 /* Try to replace all non-SET_DEST occurrences of FROM in INSN with TO.
-   Returns non-zero is successful.  */
+   Returns nonzero is successful.  */
 
 static int
 try_replace_reg (from, to, insn)
@@ -4146,7 +4146,7 @@ constprop_register (insn, from, to, alter_jumps)
 }
 
 /* Perform constant and copy propagation on INSN.
-   The result is non-zero if a change was made.  */
+   The result is nonzero if a change was made.  */
 
 static int
 cprop_insn (insn, alter_jumps)
@@ -4407,7 +4407,7 @@ local_cprop_pass (alter_jumps)
 }
 
 /* Forward propagate copies.  This includes copies and constants.  Return
-   non-zero if a change was made.  */
+   nonzero if a change was made.  */
 
 static int
 cprop (alter_jumps)
@@ -4838,7 +4838,7 @@ compute_pre_data ()
 \f
 /* PRE utilities */
 
/* Return non-zero if an occurrence of expression EXPR in OCCR_BB would reach
    block BB.
 
    VISITED is a pointer to a working buffer for tracking which BB's have
@@ -5294,7 +5294,7 @@ gcse_emit_move_after (src, dest, insn)
    the expression into the result of the SET.  It is left to later passes
    (cprop, cse2, flow, combine, regmove) to propagate the copy or eliminate it.
 
-   Returns non-zero if a change is made.  */
+   Returns nonzero if a change is made.  */
 
 static int
 pre_delete ()
@@ -5419,7 +5419,7 @@ pre_gcse ()
 
 /* Top level routine to perform one PRE GCSE pass.
 
-   Return non-zero if a change was made.  */
+   Return nonzero if a change was made.  */
 
 static int
 one_pre_gcse_pass (pass)
@@ -6192,7 +6192,7 @@ hoist_code ()
 
 /* Top level routine to perform one code hoisting (aka unification) pass
 
-   Return non-zero if a change was made.  */
+   Return nonzero if a change was made.  */
 
 static int
 one_code_hoisting_pass ()
@@ -6658,7 +6658,7 @@ reg_set_info (dest, setter, data)
     SET_BIT (*regvec, REGNO (dest));
 }
 
/* Return non-zero if the register operands of expression X are killed
    anywhere in basic block BB.  */
 
 static int
@@ -7131,7 +7131,7 @@ insert_insn_start_bb (insn, bb)
 }
 
 /* This routine will insert a store on an edge. EXPR is the ldst entry for
-   the memory reference, and E is the edge to insert it on.  Returns non-zero
+   the memory reference, and E is the edge to insert it on.  Returns nonzero
    if an edge insertion was performed.  */
 
 static int
index f5b2681308b2f0a3c2ba0de9379fbbcc3012717f..bbc5a45c3eb7854291e394fb24a9162716f7530f 100644 (file)
@@ -2093,7 +2093,7 @@ expand_units ()
             fill the unit given the minimum issue delay.  FILL-TIME is the
             constant "MIN (ISSUE-DELAY (*,*)) * (SIMULTANEITY - 1)", and
             the simultaneity constraint is "READY-COST (E) - FILL-TIME"
-            if SIMULTANEITY is non-zero and zero otherwise.
+            if SIMULTANEITY is nonzero and zero otherwise.
 
             Thus, BLOCKAGE (E,C) when SIMULTANEITY is zero is
 
@@ -4315,7 +4315,7 @@ count_alternatives (exp)
   return 0;
 }
 \f
/* Returns non-zero if the given expression contains an EQ_ATTR with the
    `alternative' attribute.  */
 
 static int
@@ -4348,7 +4348,7 @@ compares_alternatives_p (exp)
   return 0;
 }
 \f
/* Returns non-zero is INNER is contained in EXP.  */
 
 static int
 contained_in_p (inner, exp)
@@ -4558,7 +4558,7 @@ gen_unit (def, lineno)
 /* Given a piece of RTX, print a C expression to test its truth value.
    We use AND and IOR both for logical and bit-wise operations, so
    interpret them as logical unless they are inside a comparison expression.
-   The first bit of FLAGS will be non-zero in that case.
+   The first bit of FLAGS will be nonzero in that case.
 
    Set the second bit of FLAGS to make references to attribute values use
    a cached local variable instead of calling a function.  */
@@ -5488,7 +5488,7 @@ write_indent (indent)
 }
 \f
 /* Write a subroutine that is given an insn that requires a delay slot, a
-   delay slot ordinal, and a candidate insn.  It returns non-zero if the
+   delay slot ordinal, and a candidate insn.  It returns nonzero if the
    candidate can be placed in the specified delay slot of the insn.
 
    We can write as many as three subroutines.  `eligible_for_delay'
@@ -5807,7 +5807,7 @@ next_comma_elt (pstr)
 }
 
 /* Return a `struct attr_desc' pointer for a given named attribute.  If CREATE
-   is non-zero, build a new attribute, if one does not exist.  */
+   is nonzero, build a new attribute, if one does not exist.  */
 
 static struct attr_desc *
 find_attr (name, create)
index d7709b0eb4a46ff8f0cf3c3e3841084901dbb9ad..795e312035654544cbf39bed6aa5e4155df7653a 100644 (file)
@@ -55,10 +55,10 @@ static void gen_split PARAMS ((rtx));
 static void gen_peephole PARAMS ((rtx));
 static void gen_peephole2 PARAMS ((rtx));
 
/* RECOG_P will be non-zero if this pattern was seen in a context where it will
    be used to recognize, rather than just generate an insn. 
 
-   NON_PC_SET_SRC will be non-zero if this pattern was seen in a SET_SRC
+   NON_PC_SET_SRC will be nonzero if this pattern was seen in a SET_SRC
    of a SET whose destination is not (pc).  */
 
 static void
index 7709eb8b6a65b963fbcfc1240fb6a3cf5874908f..9900b990a66138fdfe96777d7f5b3f164de7873b 100644 (file)
@@ -1200,7 +1200,7 @@ maybe_both_true_1 (d1, d2)
    D1 and D2.  Otherwise, return 1 (it may be that there is an RTL that
    can match both or just that we couldn't prove there wasn't such an RTL).
 
-   TOPLEVEL is non-zero if we are to only look at the top level and not
+   TOPLEVEL is nonzero if we are to only look at the top level and not
    recursively descend.  */
 
 static int
@@ -1677,7 +1677,7 @@ find_afterward (head, real_afterward)
 \f
 /* Assuming that the state of argument is denoted by OLDPOS, take whatever
    actions are necessary to move to NEWPOS.  If we fail to move to the
-   new state, branch to node AFTERWARD if non-zero, otherwise return.
+   new state, branch to node AFTERWARD if nonzero, otherwise return.
 
    Failure to move to the new state can only occur if we are trying to
    match multiple insns and we try to step past the end of the stream.  */
index 294bdfc49e4a4653ff7b53a1a244e82755a1aa99..9a2c03ef721184843d2a841a9c8d8736cca9d0a5 100644 (file)
@@ -405,7 +405,7 @@ static void poison_pages PARAMS ((void));
 
 void debug_print_page_list PARAMS ((int));
 \f
/* Returns non-zero if P was allocated in GC'able memory.  */
 
 static inline int
 ggc_allocated_p (p)
@@ -874,7 +874,7 @@ static unsigned char size_lookup[257] =
   8
 };
 
/* Allocate a chunk of memory of SIZE bytes.  If ZERO is non-zero, the
    memory is zeroed; otherwise, its contents are undefined.  */
 
 void *
@@ -130,7 +130,7 @@ __fetch_long (dest, source, bytes)
 }
 
-/* Write a BYTES*8-bit quantity to FILE, portably. Returns a non-zero
+/* Write a BYTES*8-bit quantity to FILE, portably. Returns a nonzero
    value if the write fails, or if VALUE can't be stored in BYTES*8
    bits.
@@ -297,12 +297,12 @@ static FILE *debug_stderr;
 static struct obstack gcse_obstack;
 
-/* Non-zero for each mode that supports (set (reg) (reg)).
+/* Nonzero for each mode that supports (set (reg) (reg)).
    This is trivially true for integer and floating point values.
    It may or may not be true for condition codes.  */
@@ -297,12 +297,12 @@ static FILE *debug_stderr;
 static char can_copy_p[(int) NUM_MACHINE_MODES];
 
-/* Non-zero if can_copy_p has been initialized.  */
+/* Nonzero if can_copy_p has been initialized.  */
 static int can_copy_init_p;
 
@@ -344,9 +344,9 @@ struct occr
   /* The insn that computes the expression.  */
   rtx insn;
-  /* Non-zero if this [anticipatable] occurrence has been deleted.  */
+  /* Nonzero if this [anticipatable] occurrence has been deleted.  */
   char deleted_p;
@@ -344,9 +344,9 @@ struct occr
   char deleted_p;
-  /* Non-zero if this [available] occurrence has been copied to
+  /* Nonzero if this [available] occurrence has been copied to
      reaching_reg.  */
   /* ??? This is mutually exclusive with deleted_p, so they could share
@@ -1341,7 +1341,7 @@ want_to_gcse_p (x)
 }
 
-/* Return non-zero if the operands of expression X are unchanged from the
+/* Return nonzero if the operands of expression X are unchanged from the
    start of INSN's basic block up to but not including INSN (if AVAIL_P == 0),
    or from INSN to the end of INSN's basic block (if AVAIL_P != 0).  */
@@ -1524,7 +1524,7 @@ load_killed_in_block_p (bb, uid_limit, x, avail_p)
 }
 
-/* Return non-zero if the operands of expression X are unchanged from
+/* Return nonzero if the operands of expression X are unchanged from
    the start of INSN's basic block up to but not including INSN.  */
 
@@ -1534,7 +1534,7 @@ oprs_anticipatable_p (x, insn)
 }
 
-/* Return non-zero if the operands of expression X are unchanged from
+/* Return nonzero if the operands of expression X are unchanged from
    INSN to the end of INSN's basic block.  */
 
@@ -1787,7 +1787,7 @@ hash_set (regno, hash_table_size)
 }
 
-/* Return non-zero if exp1 is equivalent to exp2.
+/* Return nonzero if exp1 is equivalent to exp2.
    ??? Borrowed from cse.c.  Might want to remerge with cse.c.  Later.  */
 
@@ -2740,7 +2740,7 @@ reset_opr_set_tables ()
 }
 
-/* Return non-zero if the operands of X are not set before INSN in
+/* Return nonzero if the operands of X are not set before INSN in
    INSN's basic block.  */
 
@@ -3068,7 +3068,7 @@ compute_ae_gen (expr_hash_table)
 }
 
-/* Return non-zero if expression X is killed in BB.  */
+/* Return nonzero if expression X is killed in BB.  */
 
 static int
@@ -3157,9 +3157,9 @@ compute_ae_kill (ae_gen, ae_kill, expr_hash_table)
 /* Actually perform the Classic GCSE optimizations.  */
 
-/* Return non-zero if occurrence OCCR of expression EXPR reaches block BB.
+/* Return nonzero if occurrence OCCR of expression EXPR reaches block BB.
 
@@ -3318,7 +3318,7 @@ computing_insn (expr, insn)
 }
 
-/* Return non-zero if the definition in DEF_INSN can reach INSN.
+/* Return nonzero if the definition in DEF_INSN can reach INSN.
    Only called by can_disregard_other_sets.  */
 
@@ -3352,7 +3352,7 @@ def_reaches_here_p (insn, def_insn)
 }
 
-/* Return non-zero if *ADDR_THIS_REG can only have one value at INSN.  The
+/* Return nonzero if *ADDR_THIS_REG can only have one value at INSN.  The
    value returned is the number of definitions that reach INSN.  Returning a
    value of zero means that [maybe] more than one definition reaches INSN and
@@ -4838,7 +4838,7 @@ compute_pre_data ()
 /* PRE utilities */
 
-/* Return non-zero if an occurrence of expression EXPR in OCCR_BB would reach
+/* Return nonzero if an occurrence of expression EXPR in OCCR_BB would reach
    block BB.
 
@@ -6658,7 +6658,7 @@ reg_set_info (dest, setter, data)
 }
 
-/* Return non-zero if the register operands of expression X are killed
+/* Return nonzero if the register operands of expression X are killed
    anywhere in basic block BB.  */
 
@@ -4315,7 +4315,7 @@ count_alternatives (exp)
 }
 \f
-/* Returns non-zero if the given expression contains an EQ_ATTR with the
+/* Returns nonzero if the given expression contains an EQ_ATTR with the
    `alternative' attribute.  */
 
@@ -4348,7 +4348,7 @@ compares_alternatives_p (exp)
 }
 \f
-/* Returns non-zero is INNER is contained in EXP.  */
+/* Returns nonzero is INNER is contained in EXP.  */
 
 static int
@@ -55,10 +55,10 @@ static void gen_split PARAMS ((rtx));
 static void gen_peephole2 PARAMS ((rtx));
 
-/* RECOG_P will be non-zero if this pattern was seen in a context where it will
+/* RECOG_P will be nonzero if this pattern was seen in a context where it will
    be used to recognize, rather than just generate an insn. 
 
@@ -405,7 +405,7 @@ static void poison_pages PARAMS ((void));
 void debug_print_page_list PARAMS ((int));
 \f
-/* Returns non-zero if P was allocated in GC'able memory.  */
+/* Returns nonzero if P was allocated in GC'able memory.  */
 
 static inline int
@@ -874,7 +874,7 @@ static unsigned char size_lookup[257] =
 };
 
-/* Allocate a chunk of memory of SIZE bytes.  If ZERO is non-zero, the
+/* Allocate a chunk of memory of SIZE bytes.  If ZERO is nonzero, the
    memory is zeroed; otherwise, its contents are undefined.  */
 
index b672cbecfaf86500814b3eb01893ded4b0b597cd..4cd6242ee92cf3b8978aad0f1668d83b7f510d0c 100644 (file)
--- a/gcc/ggc.h
+++ b/gcc/ggc.h
@@ -130,7 +130,7 @@ extern void ggc_collect                     PARAMS ((void));
 
 /* Actually set the mark on a particular region of memory, but don't
    follow pointers.  This function is called by ggc_mark_*.  It
-   returns zero if the object was not previously marked; non-zero if
+   returns zero if the object was not previously marked; nonzero if
    the object was already marked, or if, for any other reason,
    pointers in this data structure should not be traversed.  */
 extern int ggc_set_mark                        PARAMS ((const void *));
index d7950fa9aa29112d485f03ab0730fcfadf4efba6..a100096238043e132b04d3ae6d8b4d7b1efdecf6 100644 (file)
@@ -951,7 +951,7 @@ prune_preferences ()
    of a long enough stretch of hard regs none of which conflicts with ALLOCNO.
    The registers marked in PREFREGS are tried first.
 
-   LOSERS, if non-zero, is a HARD_REG_SET indicating registers that cannot
+   LOSERS, if nonzero, is a HARD_REG_SET indicating registers that cannot
    be used for this allocation.
 
    If ALT_REGS_P is zero, consider only the preferred class of ALLOCNO's reg.
index 97f4f49ebb2d3844046ad7956db40a53b25f4e7a..113fa5b79018e71c475012ae95f3ff2c0529410b 100644 (file)
@@ -348,7 +348,7 @@ typedef void* __gthread_mutex_t;
 #if __MINGW32_MAJOR_VERSION >= 1 || \
   (__MINGW32_MAJOR_VERSION == 0 && __MINGW32_MINOR_VERSION > 2)
 #define MINGW32_SUPPORTS_MT_EH 1
/* Mingw runtime >= v0.3 provides a magic variable that is set to non-zero
    if -mthreads option was specified, or 0 otherwise. This is to get around
    the lack of weak symbols in PE-COFF.  */
 extern int _CRT_MT;
index 3f2a11f15167c664fd7fe693578ce1bbb37e4943..0e54e48b1cfcbe2ed87e6b3927c9b520a207c49e 100644 (file)
@@ -1295,7 +1295,7 @@ expand_inline_function (fndecl, parms, target, ignore, type,
 
    Copying is done in two passes, first the insns and then their REG_NOTES.
 
-   If static_chain_value is non-zero, it represents the context-pointer
+   If static_chain_value is nonzero, it represents the context-pointer
    register for the function.  */
 
 static void
index 3b9dc616065979390b56a4a90143a7965d351f04..5fef7b7311f5edb338e13797b623ca0eeecf731a 100644 (file)
@@ -962,7 +962,7 @@ signed_condition (code)
     }
 }
 \f
/* Return non-zero if CODE1 is more strict than CODE2, i.e., if the
    truth of CODE1 implies the truth of CODE2.  */
 
 int
@@ -1255,7 +1255,7 @@ onlyjump_p (insn)
 
 #ifdef HAVE_cc0
 
/* Return non-zero if X is an RTX that only sets the condition codes
    and has no side effects.  */
 
 int
index 54332b82e2b797f4df6b8a8170430d3da5e79366..ccbb53485aa713c53410072bd9949cca05c0abeb 100644 (file)
@@ -260,7 +260,7 @@ lhd_decl_printable_name (decl, verbosity)
    completely handled within this function, it should set *SUBTREES to
    0, so that generic handling isn't attempted.  For language-specific
    tree codes, generic handling would abort(), so make sure it is set
-   properly.  Both SUBTREES and *SUBTREES is guaranteed to be non-zero
+   properly.  Both SUBTREES and *SUBTREES is guaranteed to be nonzero
    when the function is called.  */
 
 tree
@@ -376,7 +376,7 @@ lhd_tree_inlining_anon_aggr_type_p (t)
 
 /* lang_hooks.tree_inlining.start_inlining and end_inlining perform any
    language-specific bookkeeping necessary for processing
-   FN. start_inlining returns non-zero if inlining should proceed, zero if
+   FN. start_inlining returns nonzero if inlining should proceed, zero if
    not.
 
    For instance, the C++ version keeps track of template instantiations to
@@ -408,7 +408,7 @@ lhd_tree_inlining_convert_parm_for_inlining (parm, value, fndecl)
 }
 
 /* lang_hooks.tree_dump.dump_tree:  Dump language-specific parts of tree
-   nodes.  Returns non-zero if it does not want the usual dumping of the
+   nodes.  Returns nonzero if it does not want the usual dumping of the
    second argument.  */
 
 int
index 993d970ad58e18d5d702d8958346cc7fac92e285..0518afed0ef729b61870dbaafca08dd7536a8767 100644 (file)
@@ -78,7 +78,7 @@ struct lang_hooks_for_functions
 
 struct lang_hooks_for_tree_dump
 {
/* Dump language-specific parts of tree nodes.  Returns non-zero if it
      does not want the usual dumping of the second argument.  */
   int (*dump_tree) PARAMS ((void *, tree));
 
@@ -142,7 +142,7 @@ struct lang_hooks_for_decls
      FUNCTIONBODY -- nonzero if this level is the body of a function.  */
   tree (*poplevel) PARAMS ((int, int, int));
 
/* Returns non-zero if we are in the global binding level.  Ada
      returns -1 for an undocumented reason used in stor-layout.c.  */
   int (*global_bindings_p) PARAMS ((void));
 
@@ -201,7 +201,7 @@ struct lang_hooks
      Should return zero unless the compiler back-end does not need to
      be initialized, such as with the -E option.
      
-     If errorcount is non-zero after this call the compiler exits
+     If errorcount is nonzero after this call the compiler exits
      immediately and the finish hook is not called.  */
   bool (*post_options) PARAMS ((void));
 
@@ -216,7 +216,7 @@ struct lang_hooks
   /* Called at the end of compilation, as a finalizer.  */
   void (*finish) PARAMS ((void));
 
/* Parses the entire file.  The argument is non-zero to cause bison
      parsers to dump debugging information during parsing.  */
   void (*parse_file) PARAMS ((int));
 
index 835cb3177531f459d5a30026a49a32d72b026c53..60201887f491fd9826c5e4733ed909e22a81d0ce 100644 (file)
@@ -109,7 +109,7 @@ extern void print_containing_files
 /* Returns the map a given map was included from.  */
 #define INCLUDED_FROM(SET, MAP) (&(SET)->maps[(MAP)->included_from])
 
/* Non-zero if the map is at the bottom of the include stack.  */
 #define MAIN_FILE_P(MAP) ((MAP)->included_from < 0)
 
 /* The current line map.  Saves a call to lookup_line if the caller is
index 04e2fbe5a4c7cc5951bb03cc6b223b34b7cc8ac7..9c94924aec92e896023bad355b785451dd524d85 100644 (file)
@@ -577,7 +577,7 @@ equiv_init_varies_p (x)
   return 0;
 }
 
/* Returns non-zero if X (used to initialize register REGNO) is movable.
    X is only movable if the registers it uses have equivalent initializations
    which appear to be within the same loop (or in an inner loop) and movable
    or if they are not candidates for local_alloc and don't vary.  */
@@ -1778,11 +1778,11 @@ qty_sugg_compare_1 (q1p, q2p)
    If we really combined them, we could lose if the pseudo lives
    across an insn that clobbers the hard reg (eg, movstr).
 
-   ALREADY_DEAD is non-zero if USEDREG is known to be dead even though
+   ALREADY_DEAD is nonzero if USEDREG is known to be dead even though
    there is no REG_DEAD note on INSN.  This occurs during the processing
    of REG_NO_CONFLICT blocks.
 
-   MAY_SAVE_COPYCOPY is non-zero if this insn is simply copying USEDREG to
+   MAY_SAVE_COPYCOPY is nonzero if this insn is simply copying USEDREG to
    SETREG or if the input and output must share a register.
    In that case, we record a hard reg suggestion in QTY_PHYS_COPY_SUGG.
 
@@ -2099,7 +2099,7 @@ reg_is_born (reg, birth)
     }
 }
 
/* Record the death of REG in the current insn.  If OUTPUT_P is non-zero,
    REG is an output that is dying (i.e., it is never used), otherwise it
    is an input (the normal case).
    If OUTPUT_P is 1, then we extend the life past the end of this insn.  */
@@ -2168,7 +2168,7 @@ wipe_dead_reg (reg, output_p)
    If QTYNO crosses calls, insist on a register preserved by calls,
    unless ACCEPT_CALL_CLOBBERED is nonzero.
 
-   If JUST_TRY_SUGGESTED is non-zero, only try to see if the suggested
+   If JUST_TRY_SUGGESTED is nonzero, only try to see if the suggested
    register is available.  If not, return -1.  */
 
 static int
@@ -2327,7 +2327,7 @@ find_free_reg (class, mode, qtyno, accept_call_clobbered, just_try_suggested,
 }
 \f
 /* Mark that REGNO with machine-mode MODE is live starting from the current
-   insn (if LIFE is non-zero) or dead starting at the current insn (if LIFE
+   insn (if LIFE is nonzero) or dead starting at the current insn (if LIFE
    is zero).  */
 
 static void
@@ -2346,7 +2346,7 @@ mark_life (regno, mode, life)
 }
 
 /* Mark register number REGNO (with machine-mode MODE) as live (if LIFE
-   is non-zero) or dead (if LIFE is zero) from insn number BIRTH (inclusive)
+   is nonzero) or dead (if LIFE is zero) from insn number BIRTH (inclusive)
    to insn number DEATH (exclusive).  */
 
 static void
index a593150ec318a277a6a84f263d2c81f864fe2b80..ca1dc7b3b4d72ba2b4d30faa52c57c1368fe238d 100644 (file)
@@ -66,7 +66,7 @@
    is rounded towards 0.
 
    5) count_leading_zeros(count, x) counts the number of zero-bits from the
-   msb to the first non-zero bit in the UWtype X.  This is the number of
+   msb to the first nonzero bit in the UWtype X.  This is the number of
    steps X needs to be shifted left to set the msb.  Undefined for X == 0,
    unless the symbol COUNT_LEADING_ZEROS_0 is defined to some value.
 
index 1e2709f8aaef7e4158f357c27d9bccdc4ceb460f..0a7fa9b262c3a9e50447bd6793bc30e7c991d22b 100644 (file)
@@ -4222,7 +4222,7 @@ emit_prefetch_instructions (loop)
 
 static rtx note_insn;
 
/* Dummy register to have non-zero DEST_REG for DEST_ADDR type givs.  */
 
 static rtx addr_placeholder;
 
@@ -4594,7 +4594,7 @@ loop_givs_check (loop)
 }
 
 
/* Return non-zero if it is possible to eliminate the biv BL provided
    all givs are reduced.  This is possible if either the reg is not
    used outside the loop, or we can compute what its final value will
    be.  */
@@ -6498,7 +6498,7 @@ general_induction_var (loop, x, src_reg, add_val, mult_val, ext_val,
    expression that is neither invariant nor a biv or giv), this routine
    returns 0.
 
-   For a non-zero return, the result will have a code of CONST_INT, USE,
+   For a nonzero return, the result will have a code of CONST_INT, USE,
    REG (for a BIV), PLUS, or MULT.  No other codes will occur.
 
    *BENEFIT will be incremented by the benefit of any sub-giv encountered.  */
@@ -6851,7 +6851,7 @@ simplify_giv_expr (loop, x, ext_val, benefit)
                      return simplify_giv_expr (loop, m->match->set_dest,
                                                ext_val, benefit);
 
/* If consec is non-zero, this is a member of a group of
                       instructions that were moved together.  We handle this
                       case only to the point of seeking to the last insn and
                       looking for a REG_EQUAL.  Fail if we don't find one.  */
@@ -8586,7 +8586,7 @@ check_dbra_loop (loop, insn_count)
 /* Verify whether the biv BL appears to be eliminable,
    based on the insns in the loop that refer to it.
 
-   If ELIMINATE_P is non-zero, actually do the elimination.
+   If ELIMINATE_P is nonzero, actually do the elimination.
 
    THRESHOLD and INSN_COUNT are from loop_optimize and are used to
    determine whether invariant insns should be placed inside or at the
@@ -8658,7 +8658,7 @@ maybe_eliminate_biv (loop, bl, eliminate_p, threshold, insn_count)
 }
 \f
 /* INSN and REFERENCE are instructions in the same insn chain.
-   Return non-zero if INSN is first.  */
+   Return nonzero if INSN is first.  */
 
 int
 loop_insn_first_p (insn, reference)
@@ -8691,7 +8691,7 @@ loop_insn_first_p (insn, reference)
     }
 }
 
/* We are trying to eliminate BIV in INSN using GIV.  Return non-zero if
    the offset that we have to take into account due to auto-increment /
    div derivation is zero.  */
 static int
@@ -8718,10 +8718,10 @@ biv_elimination_giv_has_0_offset (biv, giv, insn)
 
    If BIV does not appear in X, return 1.
 
-   If ELIMINATE_P is non-zero, actually do the elimination.
+   If ELIMINATE_P is nonzero, actually do the elimination.
    WHERE_INSN/WHERE_BB indicate where extra insns should be added.
    Depending on how many items have been moved out of the loop, it
-   will either be before INSN (when WHERE_INSN is non-zero) or at the
+   will either be before INSN (when WHERE_INSN is nonzero) or at the
    start of the loop (when WHERE_INSN is zero).  */
 
 static int
@@ -9191,14 +9191,14 @@ update_reg_last_use (x, insn)
    If the condition cannot be understood, or is an inequality floating-point
    comparison which needs to be reversed, 0 will be returned.
 
-   If REVERSE is non-zero, then reverse the condition prior to canonizing it.
+   If REVERSE is nonzero, then reverse the condition prior to canonizing it.
 
-   If EARLIEST is non-zero, it is a pointer to a place where the earliest
+   If EARLIEST is nonzero, it is a pointer to a place where the earliest
    insn used in locating the condition was found.  If a replacement test
    of the condition is desired, it should be placed in front of that
    insn and we will be sure that the inputs are still valid.
 
-   If WANT_REG is non-zero, we wish the condition to be relative to that
+   If WANT_REG is nonzero, we wish the condition to be relative to that
    register, if possible.  Therefore, do not canonicalize the condition
    further.  */
 
@@ -9240,7 +9240,7 @@ canonicalize_condition (insn, cond, reverse, earliest, want_reg)
         && op1 == CONST0_RTX (GET_MODE (op0))
         && op0 != want_reg)
     {
/* Set non-zero when we find something of interest.  */
       rtx x = 0;
 
 #ifdef HAVE_cc0
@@ -9448,7 +9448,7 @@ canonicalize_condition (insn, cond, reverse, earliest, want_reg)
    inequality floating-point comparison which needs to be reversed, 0 will
    be returned.
 
-   If EARLIEST is non-zero, it is a pointer to a place where the earliest
+   If EARLIEST is nonzero, it is a pointer to a place where the earliest
    insn used in locating the condition was found.  If a replacement test
    of the condition is desired, it should be placed in front of that
    insn and we will be sure that the inputs are still valid.  */
@@ -10448,7 +10448,7 @@ loop_insn_emit_after (loop, where_bb, where_insn, pattern)
 }
 
 
/* If WHERE_INSN is non-zero emit insn for PATTERN before WHERE_INSN
    in basic block WHERE_BB (ignored in the interim) within the loop
    otherwise hoist PATTERN into the loop pre-header.  */
 
index 13b629311d4676e5b2e3b3337895dee45d6106f4..d5fe0436dada2468e95a246f8fd640ee61eefbae 100644 (file)
@@ -145,7 +145,7 @@ struct induction
                                   same biv register.  */
   struct induction *same;      /* If this giv has been combined with another
                                   giv, this points to the base giv.  The base
-                                  giv will have COMBINED_WITH non-zero.  */
+                                  giv will have COMBINED_WITH nonzero.  */
   HOST_WIDE_INT const_adjust;  /* Used by loop unrolling, when an address giv
                                   is split, and a constant is eliminated from
                                   the address, the -constant is stored here
@@ -377,7 +377,7 @@ struct loop_info
   struct loop_regs regs;
   /* The induction variable information in loop.  */
   struct loop_ivs ivs;
/* Non-zero if call is in pre_header extended basic block.  */
   int pre_header_has_call;
 };
@@ -348,7 +348,7 @@ typedef void* __gthread_mutex_t;
   (__MINGW32_MAJOR_VERSION == 0 && __MINGW32_MINOR_VERSION > 2)
 #define MINGW32_SUPPORTS_MT_EH 1
-/* Mingw runtime >= v0.3 provides a magic variable that is set to non-zero
+/* Mingw runtime >= v0.3 provides a magic variable that is set to nonzero
    if -mthreads option was specified, or 0 otherwise. This is to get around
    the lack of weak symbols in PE-COFF.  */
@@ -962,7 +962,7 @@ signed_condition (code)
 }
 \f
-/* Return non-zero if CODE1 is more strict than CODE2, i.e., if the
+/* Return nonzero if CODE1 is more strict than CODE2, i.e., if the
    truth of CODE1 implies the truth of CODE2.  */
 
@@ -1255,7 +1255,7 @@ onlyjump_p (insn)
 #ifdef HAVE_cc0
 
-/* Return non-zero if X is an RTX that only sets the condition codes
+/* Return nonzero if X is an RTX that only sets the condition codes
    and has no side effects.  */
 
@@ -78,7 +78,7 @@ struct lang_hooks_for_functions
 struct lang_hooks_for_tree_dump
 {
-  /* Dump language-specific parts of tree nodes.  Returns non-zero if it
+  /* Dump language-specific parts of tree nodes.  Returns nonzero if it
      does not want the usual dumping of the second argument.  */
   int (*dump_tree) PARAMS ((void *, tree));
@@ -142,7 +142,7 @@ struct lang_hooks_for_decls
   tree (*poplevel) PARAMS ((int, int, int));
 
-  /* Returns non-zero if we are in the global binding level.  Ada
+  /* Returns nonzero if we are in the global binding level.  Ada
      returns -1 for an undocumented reason used in stor-layout.c.  */
   int (*global_bindings_p) PARAMS ((void));
@@ -216,7 +216,7 @@ struct lang_hooks
   void (*finish) PARAMS ((void));
 
-  /* Parses the entire file.  The argument is non-zero to cause bison
+  /* Parses the entire file.  The argument is nonzero to cause bison
      parsers to dump debugging information during parsing.  */
   void (*parse_file) PARAMS ((int));
@@ -109,7 +109,7 @@ extern void print_containing_files
 #define INCLUDED_FROM(SET, MAP) (&(SET)->maps[(MAP)->included_from])
 
-/* Non-zero if the map is at the bottom of the include stack.  */
+/* Nonzero if the map is at the bottom of the include stack.  */
 #define MAIN_FILE_P(MAP) ((MAP)->included_from < 0)
 
@@ -577,7 +577,7 @@ equiv_init_varies_p (x)
 }
 
-/* Returns non-zero if X (used to initialize register REGNO) is movable.
+/* Returns nonzero if X (used to initialize register REGNO) is movable.
    X is only movable if the registers it uses have equivalent initializations
    which appear to be within the same loop (or in an inner loop) and movable
@@ -2099,7 +2099,7 @@ reg_is_born (reg, birth)
 }
 
-/* Record the death of REG in the current insn.  If OUTPUT_P is non-zero,
+/* Record the death of REG in the current insn.  If OUTPUT_P is nonzero,
    REG is an output that is dying (i.e., it is never used), otherwise it
    is an input (the normal case).
@@ -4222,7 +4222,7 @@ emit_prefetch_instructions (loop)
 static rtx note_insn;
 
-/* Dummy register to have non-zero DEST_REG for DEST_ADDR type givs.  */
+/* Dummy register to have nonzero DEST_REG for DEST_ADDR type givs.  */
 
 static rtx addr_placeholder;
@@ -4594,7 +4594,7 @@ loop_givs_check (loop)
 
 
-/* Return non-zero if it is possible to eliminate the biv BL provided
+/* Return nonzero if it is possible to eliminate the biv BL provided
    all givs are reduced.  This is possible if either the reg is not
    used outside the loop, or we can compute what its final value will
@@ -6851,7 +6851,7 @@ simplify_giv_expr (loop, x, ext_val, benefit)
                                                ext_val, benefit);
 
-                   /* If consec is non-zero, this is a member of a group of
+                   /* If consec is nonzero, this is a member of a group of
                       instructions that were moved together.  We handle this
                       case only to the point of seeking to the last insn and
@@ -8691,7 +8691,7 @@ loop_insn_first_p (insn, reference)
 }
 
-/* We are trying to eliminate BIV in INSN using GIV.  Return non-zero if
+/* We are trying to eliminate BIV in INSN using GIV.  Return nonzero if
    the offset that we have to take into account due to auto-increment /
    div derivation is zero.  */
@@ -9240,7 +9240,7 @@ canonicalize_condition (insn, cond, reverse, earliest, want_reg)
         && op0 != want_reg)
     {
-      /* Set non-zero when we find something of interest.  */
+      /* Set nonzero when we find something of interest.  */
       rtx x = 0;
 
@@ -10448,7 +10448,7 @@ loop_insn_emit_after (loop, where_bb, where_insn, pattern)
 
 
-/* If WHERE_INSN is non-zero emit insn for PATTERN before WHERE_INSN
+/* If WHERE_INSN is nonzero emit insn for PATTERN before WHERE_INSN
    in basic block WHERE_BB (ignored in the interim) within the loop
    otherwise hoist PATTERN into the loop pre-header.  */
@@ -377,7 +377,7 @@ struct loop_info
   /* The induction variable information in loop.  */
   struct loop_ivs ivs;
-  /* Non-zero if call is in pre_header extended basic block.  */
+  /* Nonzero if call is in pre_header extended basic block.  */
   int pre_header_has_call;
 };